package com.ruoyi.szxc.mapper;

import com.ruoyi.szxc.domain.SzxcZcss;

import java.util.List;

/**
 * 资产设施Mapper接口
 * 
 * @author hs
 * @date 2024-04-02
 */
public interface SzxcZcssMapper 
{
    /**
     * 查询资产设施
     * 
     * @param id 资产设施主键
     * @return 资产设施
     */
    public SzxcZcss selectSzxcZcssById(Long id);

    /**
     * 查询资产设施列表
     * 
     * @param szxcZcss 资产设施
     * @return 资产设施集合
     */
    public List<SzxcZcss> selectSzxcZcssList(SzxcZcss szxcZcss);

    /**
     * 新增资产设施
     * 
     * @param szxcZcss 资产设施
     * @return 结果
     */
    public int insertSzxcZcss(SzxcZcss szxcZcss);

    /**
     * 修改资产设施
     * 
     * @param szxcZcss 资产设施
     * @return 结果
     */
    public int updateSzxcZcss(SzxcZcss szxcZcss);

    /**
     * 删除资产设施
     * 
     * @param id 资产设施主键
     * @return 结果
     */
    public int deleteSzxcZcssById(Long id);

    /**
     * 批量删除资产设施
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcZcssByIds(Long[] ids);
}
